@@ -32,7 +32,7 @@ class GameView : public KgDeclarativeView
     Q_OBJECT
 public:
     explicit GameView(QWidget *parent=0);
-    virtual ~GameView();
+    ~GameView() override;
     void startNewGame(uint width, uint height, Wrapping w);
     int minimumMoves() {return grid->minimumMoves();}
     int cellCount() {return grid->cellCount();}
