@@ -170,7 +170,7 @@ void MainWindow::setupActions()
     actionCollection()->addAction( QStringLiteral( "kb_turn_clockwise" ), action);
 
     action = new QAction(i18n("Keyboard: Turn counterclockwise"),this);
-    actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::Key_Return);
+    actionCollection()->setDefaultShortcut(action, Qt::CTRL | Qt::Key_Return);
     connect(action, SIGNAL(triggered()), m_view->rootObject(), SLOT(rotateCounterclockwise()));
     actionCollection()->addAction( QStringLiteral( "kb_turn_counterclockwise" ), action);
 
@@ -188,7 +188,7 @@ void MainWindow::configureSettings()
     dialog->addPage(new GeneralConfig(dialog), i18n("General"), QStringLiteral("games-config-options"));
     dialog->addPage(new KgThemeSelector(m_view->getProvider()), i18n("Theme"), QStringLiteral("games-config-theme"));
     dialog->addPage(new CustomGameConfig(dialog), i18n("Custom Game"), QStringLiteral("games-config-custom"));
-    connect(dialog, &KConfigDialog::settingsChanged, m_view, &GameView::setRotateDuration);
+    connect(dialog, &KConfigDialog::settingsChanged, m_view, &GameView::updateSettings);
 //    dialog->setHelp(QString(),QLatin1String("knetwalk"));
     dialog->show();
 }
